diff --git a/udlfb.c b/udlfb.c
index f7ad3a5..9900dd8 100644
--- a/udlfb.c
+++ b/udlfb.c
@@ -153,7 +153,7 @@ static char *rle_compress16(uint16_t * src, char *dst, int rem)
 		while (rem && *src == pix0)
 			rem--, rl++, src++;
 		*dst++ = rl;
-#ifdef _BIG_ENDIAN
+#ifndef _BIG_ENDIAN
 		*dst++ = start[0];
 		*dst++ = start[1];
 #else
@@ -279,7 +279,7 @@ image_blit(struct dlfb_data *dev_info, int x, int y, int width, int height,
 					// PUT COMPRESSION HERE
 					for (j = firstdiff * 2;
 					     j < thistime * 2; j += 2) {
-#ifdef _BIG_ENDIAN
+#ifndef _BIG_ENDIAN
 						*bufptr++ = data[j];
 						*bufptr++ = data[j+1];
 #else
@@ -327,6 +327,8 @@ draw_rect(struct dlfb_data *dev_info, int x, int y, int width, int height,
 
 	char *bufptr;
 
+	/*printk("DRAW RECT %d %d %d %d DEPTH %d.%d.%d\n", x, y, width, height, red, green, blue);*/
+
 	if (x + width > dev_info->info->var.xres)
 		return -EINVAL;
 
@@ -382,8 +384,13 @@ draw_rect(struct dlfb_data *dev_info, int x, int y, int width, int height,
 				rem = 0;
 			}
 
+#ifndef _BIG_ENDIAN
 			*bufptr++ = (char)(col >> 8);
 			*bufptr++ = (char)(col);
+#else
+			*bufptr++ = (char)(col);
+			*bufptr++ = (char)(col >> 8);
+#endif
 
 		}
 
@@ -552,7 +559,7 @@ static void dlfb_fillrect(struct fb_info *info,
 
 	mutex_unlock(&dev->fb_mutex);
 
-	/* printk("FILL RECT %d %d !!!\n", region->dx, region->dy); */
+	printk("FILL RECT %d %d !!!\n", region->dx, region->dy);
 
 }
 
@@ -910,7 +917,7 @@ static uint16_t lfsr16(uint16_t v)
 {
   uint32_t _v   = 0xFFFF;
 
-	v = cpu_to_le16(v);
+	/*v = cpu_to_le16(v);*/
 
   while (v--) {
     _v = ((_v << 1) | (((_v >> 15) ^ (_v >> 4) ^ (_v >> 2) ^ (_v >> 1)) & 1)) & 0xFFFF;
@@ -958,6 +965,21 @@ int dlfb_bulk_msg(struct dlfb_data *dev, int len)
 
 	int ret;
 
+    int i;
+    int j = 0;
+#if 0
+    printk("dlfb_bulk_msg ");
+    for (i = 0; i < len; i++)
+    {
+        j += 1;
+        printk("%02x ", (unsigned char)dev->buf[i]);
+        if (j == 16) {
+            printk("\n");
+            j = 0;
+        }
+    }
+    printk("\n");
+#endif
 	init_completion(&dev->done);
 
 	dev->tx_urb->actual_length = 0;
@@ -969,13 +991,25 @@ int dlfb_bulk_msg(struct dlfb_data *dev, int len)
 		printk("usb timeout !!!\n");
 	}
 
+#if 0
+    printk("dlfb_bulk_msg transferred %d\n", dev->tx_urb->actual_length);
+#endif
 	return dev->tx_urb->actual_length;
 
 }
 
+inline uint16_t swap_endian_s(uint16_t val)
+{
+  return ((val >> 8) & 0xFF) | ((val << 8) & 0xFF00);
+}
+
 static char *dlfb_set_register_16(char *bufptr, uint8_t reg, uint16_t val)
 {
 
+#ifdef _BIG_ENDIAN
+    val = swap_endian_s(val);
+#endif
+
 	bufptr = dlfb_set_register(bufptr, reg, val >> 8);
 	bufptr = dlfb_set_register(bufptr, reg+1, val & 0xFF);
 
@@ -984,7 +1018,9 @@ static char *dlfb_set_register_16(char *bufptr, uint8_t reg, uint16_t val)
 
 static char *dlfb_set_register_le16(char *bufptr, uint8_t reg, uint16_t val)
 {
-
+#ifdef _BIG_ENDIAN
+    val = swap_endian_s(val);
+#endif
 	bufptr = dlfb_set_register(bufptr, reg, val & 0xFF);
 	bufptr = dlfb_set_register(bufptr, reg+1, val >> 8);
 
@@ -1074,6 +1110,10 @@ char *dlfb_set_register(char *bufptr, uint8_t reg, uint8_t val)
 	*bufptr++ = reg;
 	*bufptr++ = val;
 
+#if 0
+    printk("dlfb_set_register %02x %02x\n", reg, val);
+#endif
+
 	return bufptr;
 
 }
@@ -1197,7 +1237,8 @@ int dlfb_setup(struct dlfb_data *dev)
 				strcpy(dev->chiptype, "unknown");
 	}
 
-	printk("found DisplayLink Chip %s\n", dev->chiptype);
+	printk("found DisplayLink Chip %s %d\n", dev->chiptype,
+                                             ((buf[3] >> 4) & 0xF));
 
 	// set encryption key (null)
         memcpy(dev->buf, STD_CHANNEL, 16);
@@ -1257,6 +1298,9 @@ int dlfb_activate_framebuffer(struct dlfb_data *dev, int mode)
 	info->var.activate = FB_ACTIVATE_TEST;
 	info->var.vmode = FB_VMODE_NONINTERLACED;
 
+    info->var.xres = 800;
+    info->var.yres = 480;
+
 	info->var.red.offset = 11;
 	info->var.red.length = 5;
 	info->var.red.msb_right = 0;
